==> api-0.16.3-sources.jar: eu/fispace/api/lg/ObjectFactory.java <==
//
// Este archivo ha sido generado por la arquitectura JavaTM para la implantación de la referencia de enlace (JAXB) XML v2.2.7 
// Visite <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
// Todas las modificaciones realizadas en este archivo se perderán si se vuelve a compilar el esquema de origen. 
// Generado el: 2015.10.16 a las 09:42:13 AM CEST 
//


package eu.fispace.api.lg;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the eu.fispace.api.lg package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _ReceiveRTIStatusRequestMessageReason_QNAME = new QName("", "reason");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: eu.fispace.api.lg
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link ShipmentItemType }
     * 
     */
    public ShipmentItemType createShipmentItemType() {
        return new ShipmentItemType();
    }

    /**
     * Create an instance of {@link MasterProductTypeType }
     * 
     */
    public MasterProductTypeType createMasterProductTypeType() {
        return new MasterProductTypeType();
    }

    /**
     * Create an instance of {@link ActorType }
     * 
     */
    public ActorType createActorType() {
        return new ActorType();
    }

    /**
     * Create an instance of {@link ShipmentType }
     * 
     */
    public ShipmentType createShipmentType() {
        return new ShipmentType();
    }

    /**
     * Create an instance of {@link InformationItemValueStringListType }
     * 
     */
    public InformationItemValueStringListType createInformationItemValueStringListType() {
        return new InformationItemValueStringListType();
    }

    /**
     * Create an instance of {@link ProvideShipmentDetailsRequestMessage }
     * 
     */
    public ProvideShipmentDetailsRequestMessage createProvideShipmentDetailsRequestMessage() {
        return new ProvideShipmentDetailsRequestMessage();
    }

    /**
     * Create an instance of {@link TransportPlan }
     * 
     */
    public TransportPlan createTransportPlan() {
        return new TransportPlan();
    }

    /**
     * Create an instance of {@link ReceiveShipmentStatusRequestMessage }
     * 
     */
    public ReceiveShipmentStatusRequestMessage createReceiveShipmentStatusRequestMessage() {
        return new ReceiveShipmentStatusRequestMessage();
    }

    /**
     * Create an instance of {@link LegDeadlineExceeded }
     * 
     */
    public LegDeadlineExceeded createLegDeadlineExceeded() {
        return new LegDeadlineExceeded();
    }

    /**
     * Create an instance of {@link ProvideShipmentDetailsResponseMessage }
     * 
     */
    public ProvideShipmentDetailsResponseMessage createProvideShipmentDetailsResponseMessage() {
        return new ProvideShipmentDetailsResponseMessage();
    }

    /**
     * Create an instance of {@link GetNotifications }
     * 
     */
    public GetNotifications createGetNotifications() {
        return new GetNotifications();
    }

    /**
     * Create an instance of {@link LegFinished }
     * 
     */
    public LegFinished createLegFinished() {
        return new LegFinished();
    }

    /**
     * Create an instance of {@link TICPushMessage }
     * 
     */
    public TICPushMessage createTICPushMessage() {
        return new TICPushMessage();
    }

    /**
     * Create an instance of {@link ReceiveRTIStatusRequestMessage }
     * 
     */
    public ReceiveRTIStatusRequestMessage createReceiveRTIStatusRequestMessage() {
        return new ReceiveRTIStatusRequestMessage();
    }

    /**
     * Create an instance of {@link NotifyDelay }
     * 
     */
    public NotifyDelay createNotifyDelay() {
        return new NotifyDelay();
    }

    /**
     * Create an instance of {@link Notification }
     * 
     */
    public Notification createNotification() {
        return new Notification();
    }

    /**
     * Create an instance of {@link InternalIdentificationType }
     * 
     */
    public InternalIdentificationType createInternalIdentificationType() {
        return new InternalIdentificationType();
    }

    /**
     * Create an instance of {@link InformationItemValueDateType }
     * 
     */
    public InformationItemValueDateType createInformationItemValueDateType() {
        return new InformationItemValueDateType();
    }

    /**
     * Create an instance of {@link ExternalAvailableProductsType }
     * 
     */
    public ExternalAvailableProductsType createExternalAvailableProductsType() {
        return new ExternalAvailableProductsType();
    }

    /**
     * Create an instance of {@link InformationItemType }
     * 
     */
    public InformationItemType createInformationItemType() {
        return new InformationItemType();
    }

    /**
     * Create an instance of {@link MasterPackagingTypeType }
     * 
     */
    public MasterPackagingTypeType createMasterPackagingTypeType() {
        return new MasterPackagingTypeType();
    }

    /**
     * Create an instance of {@link InformationItemValueStringType }
     * 
     */
    public InformationItemValueStringType createInformationItemValueStringType() {
        return new InformationItemValueStringType();
    }

    /**
     * Create an instance of {@link ShipmentIdentificationType }
     * 
     */
    public ShipmentIdentificationType createShipmentIdentificationType() {
        return new ShipmentIdentificationType();
    }

    /**
     * Create an instance of {@link GeoLocationType }
     * 
     */
    public GeoLocationType createGeoLocationType() {
        return new GeoLocationType();
    }

    /**
     * Create an instance of {@link InformationItemValueBooleanType }
     * 
     */
    public InformationItemValueBooleanType createInformationItemValueBooleanType() {
        return new InformationItemValueBooleanType();
    }

    /**
     * Create an instance of {@link InformationItemValueDoubleType }
     * 
     */
    public InformationItemValueDoubleType createInformationItemValueDoubleType() {
        return new InformationItemValueDoubleType();
    }

    /**
     * Create an instance of {@link ShipmentStatusUpdateType }
     * 
     */
    public ShipmentStatusUpdateType createShipmentStatusUpdateType() {
        return new ShipmentStatusUpdateType();
    }

    /**
     * Create an instance of {@link FiSpaceContactType }
     * 
     */
    public FiSpaceContactType createFiSpaceContactType() {
        return new FiSpaceContactType();
    }

    /**
     * Create an instance of {@link InformationItemValueIntegerType }
     * 
     */
    public InformationItemValueIntegerType createInformationItemValueIntegerType() {
        return new InformationItemValueIntegerType();
    }

    /**
     * Create an instance of {@link NotificationType }
     * 
     */
    public NotificationType createNotificationType() {
        return new NotificationType();
    }

    /**
     * Create an instance of {@link TransportLegType }
     * 
     */
    public TransportLegType createTransportLegType() {
        return new TransportLegType();
    }

    /**
     * Create an instance of {@link CustomProductTypeType }
     * 
     */
    public CustomProductTypeType createCustomProductTypeType() {
        return new CustomProductTypeType();
    }

    /**
     * Create an instance of {@link AddressType }
     * 
     */
    public AddressType createAddressType() {
        return new AddressType();
    }

    /**
     * Create an instance of {@link TransportPlanType }
     * 
     */
    public TransportPlanType createTransportPlanType() {
        return new TransportPlanType();
    }

    /**
     * Create an instance of {@link LocationType }
     * 
     */
    public LocationType createLocationType() {
        return new LocationType();
    }

    /**
     * Create an instance of {@link CustomPackagingTypeType }
     * 
     */
    public CustomPackagingTypeType createCustomPackagingTypeType() {
        return new CustomPackagingTypeType();
    }

    /**
     * Create an instance of {@link ShipmentItemType.ImportIDs }
     * 
     */
    public ShipmentItemType.ImportIDs createShipmentItemTypeImportIDs() {
        return new ShipmentItemType.ImportIDs();
    }

    /**
     * Create an instance of {@link ShipmentItemType.PackagingTypes }
     * 
     */
    public ShipmentItemType.PackagingTypes createShipmentItemTypePackagingTypes() {
        return new ShipmentItemType.PackagingTypes();
    }

    /**
     * Create an instance of {@link ShipmentItemType.InformationItems }
     * 
     */
    public ShipmentItemType.InformationItems createShipmentItemTypeInformationItems() {
        return new ShipmentItemType.InformationItems();
    }

    /**
     * Create an instance of {@link MasterProductTypeType.InformationItemCodes }
     * 
     */
    public MasterProductTypeType.InformationItemCodes createMasterProductTypeTypeInformationItemCodes() {
        return new MasterProductTypeType.InformationItemCodes();
    }

    /**
     * Create an instance of {@link ActorType.DeliveryAdresses }
     * 
     */
    public ActorType.DeliveryAdresses createActorTypeDeliveryAdresses() {
        return new ActorType.DeliveryAdresses();
    }

    /**
     * Create an instance of {@link ShipmentType.StatusUpdates }
     * 
     */
    public ShipmentType.StatusUpdates createShipmentTypeStatusUpdates() {
        return new ShipmentType.StatusUpdates();
    }

    /**
     * Create an instance of {@link ShipmentType.ShipmentItems }
     * 
     */
    public ShipmentType.ShipmentItems createShipmentTypeShipmentItems() {
        return new ShipmentType.ShipmentItems();
    }

    /**
     * Create an instance of {@link ShipmentType.Notifications }
     * 
     */
    public ShipmentType.Notifications createShipmentTypeNotifications() {
        return new ShipmentType.Notifications();
    }

    /**
     * Create an instance of {@link ShipmentType.InformationItems }
     * 
     */
    public ShipmentType.InformationItems createShipmentTypeInformationItems() {
        return new ShipmentType.InformationItems();
    }

    /**
     * Create an instance of {@link InformationItemValueStringListType.Value }
     * 
     */
    public InformationItemValueStringListType.Value createInformationItemValueStringListTypeValue() {
        return new InformationItemValueStringListType.Value();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "", name = "reason", scope = ReceiveRTIStatusRequestMessage.class)
    public JAXBElement<String> createReceiveRTIStatusRequestMessageReason(String value) {
        return new JAXBElement<String>(_ReceiveRTIStatusRequestMessageReason_QNAME, String.class, ReceiveRTIStatusRequestMessage.class, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "", name = "reason", scope = ReceiveShipmentStatusRequestMessage.class)
    public JAXBElement<String> createReceiveShipmentStatusRequestMessageReason(String value) {
        return new JAXBElement<String>(_ReceiveRTIStatusRequestMessageReason_QNAME, String.class, ReceiveShipmentStatusRequestMessage.class, value);
    }

}

==> api-0.16.4-sources.jar: eu/fispace/api/lg/ObjectFactory.java <==
//
// Este archivo ha sido generado por la arquitectura JavaTM para la implantación de la referencia de enlace (JAXB) XML v2.2.7 
// Visite <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
// Todas las modificaciones realizadas en este archivo se perderán si se vuelve a compilar el esquema de origen. 
// Generado el: 2015.10.21 a las 01:04:36 PM CEST 
//


package eu.fispace.api.lg;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the eu.fispace.api.lg package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _ReceiveShipmentStatusRequestMessageReason_QNAME = new QName("", "reason");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: eu.fispace.api.lg
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link ShipmentItemType }
     * 
     */
    public ShipmentItemType createShipmentItemType() {
        return new ShipmentItemType();
    }

    /**
     * Create an instance of {@link MasterProductTypeType }
     * 
     */
    public MasterProductTypeType createMasterProductTypeType() {
        return new MasterProductTypeType();
    }

    /**
     * Create an instance of {@link ActorType }
     * 
     */
    public ActorType createActorType() {
        return new ActorType();
    }

    /**
     * Create an instance of {@link ShipmentType }
     * 
     */
    public ShipmentType createShipmentType() {
        return new ShipmentType();
    }

    /**
     * Create an instance of {@link InformationItemValueStringListType }
     * 
     */
    public InformationItemValueStringListType createInformationItemValueStringListType() {
        return new InformationItemValueStringListType();
    }

    /**
     * Create an instance of {@link ProvideShipmentDetailsRequestMessage }
     * 
     */
    public ProvideShipmentDetailsRequestMessage createProvideShipmentDetailsRequestMessage() {
        return new ProvideShipmentDetailsRequestMessage();
    }

    /**
     * Create an instance of {@link TransportPlan }
     * 
     */
    public TransportPlan createTransportPlan() {
        return new TransportPlan();
    }

    /**
     * Create an instance of {@link ReceiveShipmentStatusRequestMessage }
     * 
     */
    public ReceiveShipmentStatusRequestMessage createReceiveShipmentStatusRequestMessage() {
        return new ReceiveShipmentStatusRequestMessage();
    }

    /**
     * Create an instance of {@link LegDeadlineExceeded }
     * 
     */
    public LegDeadlineExceeded createLegDeadlineExceeded() {
        return new LegDeadlineExceeded();
    }

    /**
     * Create an instance of {@link ProvideShipmentDetailsResponseMessage }
     * 
     */
    public ProvideShipmentDetailsResponseMessage createProvideShipmentDetailsResponseMessage() {
        return new ProvideShipmentDetailsResponseMessage();
    }

    /**
     * Create an instance of {@link GetNotifications }
     * 
     */
    public GetNotifications createGetNotifications() {
        return new GetNotifications();
    }

    /**
     * Create an instance of {@link LegFinished }
     * 
     */
    public LegFinished createLegFinished() {
        return new LegFinished();
    }

    /**
     * Create an instance of {@link TICPushMessage }
     * 
     */
    public TICPushMessage createTICPushMessage() {
        return new TICPushMessage();
    }

    /**
     * Create an instance of {@link ReceiveRTIStatusRequestMessage }
     * 
     */
    public ReceiveRTIStatusRequestMessage createReceiveRTIStatusRequestMessage() {
        return new ReceiveRTIStatusRequestMessage();
    }

    /**
     * Create an instance of {@link NotifyDelay }
     * 
     */
    public NotifyDelay createNotifyDelay() {
        return new NotifyDelay();
    }

    /**
     * Create an instance of {@link Notification }
     * 
     */
    public Notification createNotification() {
        return new Notification();
    }

    /**
     * Create an instance of {@link InternalIdentificationType }
     * 
     */
    public InternalIdentificationType createInternalIdentificationType() {
        return new InternalIdentificationType();
    }

    /**
     * Create an instance of {@link InformationItemValueDateType }
     * 
     */
    public InformationItemValueDateType createInformationItemValueDateType() {
        return new InformationItemValueDateType();
    }

    /**
     * Create an instance of {@link ExternalAvailableProductsType }
     * 
     */
    public ExternalAvailableProductsType createExternalAvailableProductsType() {
        return new ExternalAvailableProductsType();
    }

    /**
     * Create an instance of {@link InformationItemType }
     * 
     */
    public InformationItemType createInformationItemType() {
        return new InformationItemType();
    }

    /**
     * Create an instance of {@link MasterPackagingTypeType }
     * 
     */
    public MasterPackagingTypeType createMasterPackagingTypeType() {
        return new MasterPackagingTypeType();
    }

    /**
     * Create an instance of {@link InformationItemValueStringType }
     * 
     */
    public InformationItemValueStringType createInformationItemValueStringType() {
        return new InformationItemValueStringType();
    }

    /**
     * Create an instance of {@link ShipmentIdentificationType }
     * 
     */
    public ShipmentIdentificationType createShipmentIdentificationType() {
        return new ShipmentIdentificationType();
    }

    /**
     * Create an instance of {@link GeoLocationType }
     * 
     */
    public GeoLocationType createGeoLocationType() {
        return new GeoLocationType();
    }

    /**
     * Create an instance of {@link InformationItemValueBooleanType }
     * 
     */
    public InformationItemValueBooleanType createInformationItemValueBooleanType() {
        return new InformationItemValueBooleanType();
    }

    /**
     * Create an instance of {@link InformationItemValueDoubleType }
     * 
     */
    public InformationItemValueDoubleType createInformationItemValueDoubleType() {
        return new InformationItemValueDoubleType();
    }

    /**
     * Create an instance of {@link ShipmentStatusUpdateType }
     * 
     */
    public ShipmentStatusUpdateType createShipmentStatusUpdateType() {
        return new ShipmentStatusUpdateType();
    }

    /**
     * Create an instance of {@link FiSpaceContactType }
     * 
     */
    public FiSpaceContactType createFiSpaceContactType() {
        return new FiSpaceContactType();
    }

    /**
     * Create an instance of {@link InformationItemValueIntegerType }
     * 
     */
    public InformationItemValueIntegerType createInformationItemValueIntegerType() {
        return new InformationItemValueIntegerType();
    }

    /**
     * Create an instance of {@link NotificationType }
     * 
     */
    public NotificationType createNotificationType() {
        return new NotificationType();
    }

    /**
     * Create an instance of {@link TransportLegType }
     * 
     */
    public TransportLegType createTransportLegType() {
        return new TransportLegType();
    }

    /**
     * Create an instance of {@link CustomProductTypeType }
     * 
     */
    public CustomProductTypeType createCustomProductTypeType() {
        return new CustomProductTypeType();
    }

    /**
     * Create an instance of {@link AddressType }
     * 
     */
    public AddressType createAddressType() {
        return new AddressType();
    }

    /**
     * Create an instance of {@link TransportPlanType }
     * 
     */
    public TransportPlanType createTransportPlanType() {
        return new TransportPlanType();
    }

    /**
     * Create an instance of {@link LocationType }
     * 
     */
    public LocationType createLocationType() {
        return new LocationType();
    }

    /**
     * Create an instance of {@link CustomPackagingTypeType }
     * 
     */
    public CustomPackagingTypeType createCustomPackagingTypeType() {
        return new CustomPackagingTypeType();
    }

    /**
     * Create an instance of {@link ShipmentItemType.ImportIDs }
     * 
     */
    public ShipmentItemType.ImportIDs createShipmentItemTypeImportIDs() {
        return new ShipmentItemType.ImportIDs();
    }

    /**
     * Create an instance of {@link ShipmentItemType.PackagingTypes }
     * 
     */
    public ShipmentItemType.PackagingTypes createShipmentItemTypePackagingTypes() {
        return new ShipmentItemType.PackagingTypes();
    }

    /**
     * Create an instance of {@link ShipmentItemType.InformationItems }
     * 
     */
    public ShipmentItemType.InformationItems createShipmentItemTypeInformationItems() {
        return new ShipmentItemType.InformationItems();
    }

    /**
     * Create an instance of {@link MasterProductTypeType.InformationItemCodes }
     * 
     */
    public MasterProductTypeType.InformationItemCodes createMasterProductTypeTypeInformationItemCodes() {
        return new MasterProductTypeType.InformationItemCodes();
    }

    /**
     * Create an instance of {@link ActorType.DeliveryAdresses }
     * 
     */
    public ActorType.DeliveryAdresses createActorTypeDeliveryAdresses() {
        return new ActorType.DeliveryAdresses();
    }

    /**
     * Create an instance of {@link ShipmentType.StatusUpdates }
     * 
     */
    public ShipmentType.StatusUpdates createShipmentTypeStatusUpdates() {
        return new ShipmentType.StatusUpdates();
    }

    /**
     * Create an instance of {@link ShipmentType.ShipmentItems }
     * 
     */
    public ShipmentType.ShipmentItems createShipmentTypeShipmentItems() {
        return new ShipmentType.ShipmentItems();
    }

    /**
     * Create an instance of {@link ShipmentType.Notifications }
     * 
     */
    public ShipmentType.Notifications createShipmentTypeNotifications() {
        return new ShipmentType.Notifications();
    }

    /**
     * Create an instance of {@link ShipmentType.InformationItems }
     * 
     */
    public ShipmentType.InformationItems createShipmentTypeInformationItems() {
        return new ShipmentType.InformationItems();
    }

    /**
     * Create an instance of {@link InformationItemValueStringListType.Value }
     * 
     */
    public InformationItemValueStringListType.Value createInformationItemValueStringListTypeValue() {
        return new InformationItemValueStringListType.Value();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "", name = "reason", scope = ReceiveShipmentStatusRequestMessage.class)
    public JAXBElement<String> createReceiveShipmentStatusRequestMessageReason(String value) {
        return new JAXBElement<String>(_ReceiveShipmentStatusRequestMessageReason_QNAME, String.class, ReceiveShipmentStatusRequestMessage.class, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "", name = "reason", scope = ReceiveRTIStatusRequestMessage.class)
    public JAXBElement<String> createReceiveRTIStatusRequestMessageReason(String value) {
        return new JAXBElement<String>(_ReceiveShipmentStatusRequestMessageReason_QNAME, String.class, ReceiveRTIStatusRequestMessage.class, value);
    }

}
